@@ -9,7 +9,7 @@ BEGIN {
     $ENV{TEST2_ACTIVE} = 1;
 }
 
-our $VERSION = '1.302118';
+our $VERSION = '1.302121';
 
 
 my $INST;
@@ -113,6 +113,7 @@ our @EXPORT_OK = qw{
     test2_list_pre_subtest_callbacks
 
     test2_ipc
+    test2_has_ipc
     test2_ipc_drivers
     test2_ipc_add_driver
     test2_ipc_polling
@@ -191,6 +192,7 @@ sub test2_list_post_load_callbacks       { @{$INST->post_load_callbacks} }
 sub test2_list_pre_subtest_callbacks     { @{$INST->pre_subtest_callbacks} }
 
 sub test2_ipc                 { $INST->ipc }
+sub test2_has_ipc             { $INST->has_ipc }
 sub test2_ipc_add_driver      { $INST->add_ipc_driver(@_) }
 sub test2_ipc_drivers         { @{$INST->ipc_drivers} }
 sub test2_ipc_polling         { $INST->ipc_polling }
@@ -1363,6 +1365,10 @@ These let you access, or specify, the IPC system internals.
 
 =over 4
 
+=item $bool = test2_has_ipc()
+
+Check if IPC is enabled.
+
 =item $ipc = test2_ipc()
 
 This will return the global L<Test2::IPC::Driver> instance. If this has not yet
@@ -1508,7 +1514,7 @@ F<http://github.com/Test-More/test-more/>.
 
 =head1 COPYRIGHT
 
-Copyright 2017 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2018 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
